Atomic Simulation Environment — ASE documentation

### Navigation

- index
- modules |

# Atomic Simulation Environment

The Atomistic Simulation Environment (ASE) is a set of tools and Python modules for setting up, manipulating, running, visualizing and analyzing atomistic simulations. The code is freely available under the GNU LGPL license.

Alphabetical list of all modules:

`atom` | `atoms` | `calculators` | `constraints`
`db` | `dft` | `data` | `ga`
`gui` | `infrared` | `io` | `lattice`
`md` | `neb` | `optimize` | `parallel`
`phasediagram` | `phonons` | `spacegroup` | `structure`
`surface` | `transport` | `thermochemistry` | `units`
`utils` | `vibrations` | `visualize` |

`Calculators`:

Gaussian Mopac

## News

- ASE version 3.9.0 released (28 May 2015).
- ASE version 3.8.0 released (22 October 2013).
- ASE version 3.7.0 released (13 May 2013).
- ASE version 3.6.0 released (24 February 2012).
- Bugfix release: ASE version 3.5.1 (24 May 2011).
- ASE version 3.5.0 released (13 April 2011).
- ASE version 3.4.1 released (11 August 2010).
- ASE version 3.4 released (23 April 2010).
- ASE version 3.3 released (11 January 2010).
- ASE version 3.2 released (4 September 2009).
- ASE has reached revision 1000 (16 July 2009).
- ASE version 3.1.0 released (27 March 2009).
- Improved `ase.vibrations` module: More accurate and possibility to calculate `infrared intensities` (13 March 2009).
- ASE version 3.0.0 released (13 November 2008).
- Asap version 3.0.2 released (15 October 2008).
- An experimental abinit interface released (9 June 2008).
- Thursday April 24 will be ASE documentation-day. Ten people from CAMd/Cinf will do a “doc-sprint” from 9 to 16. (17 Apr 2008)
- The new ASE-3.0 Sphinx page is now up and running! (2 Apr 2008)
- A beta version of the new ASE-3.0 will be used for the electronic structure course at CAMd. (10 Jan 2008)

### Navigation

- index
- modules |